@@ -34,7 +34,7 @@ class PastaportoUserInfo:
 
     @classmethod
     def from_data(cls, data: dict[str, Any]):
-        return cls(id=data["id"], email=data["email"])
+        return cls(id=int(data["id"]), email=data["email"])
 
 
 @dataclass
